==> kadu_1.2.orig.tar.bz2: kadu-1.2/plugins/filedesc/translations/filedesc_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>FileDesc</source>
        <translation>FileDesc</translation>
    </message>
    <message>
        <source>File with description to synchronize</source>
        <translation>Plik z opisem do synchronizacji</translation>
    </message>
    <message>
        <source>Enter here a file, which will contain descriptions to refresh by module.</source>
        <translation>Wpisz tutaj nazwę pliku, który będzie zawierał opisy do odświeżania przez moduł.</translation>
    </message>
    <message>
        <source>If you choose status without description, module will set it automatically to similar but with description</source>
        <translation>Jeśli wybierzesz status bez opisu, moduł automatycznie ustawi analogiczny, ale z opisem</translation>
    </message>
    <message>
        <source>Allow other descriptions</source>
        <translation>Dopuść inne opisy</translation>
    </message>
    <message>
        <source>Allows you to set some custom description manualy, until file contents does not change</source>
        <translation>Umożliwia ustawienie własnego opisu dopóki zawartość pliku nie ulegnie zmianie</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Zachowanie</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Opis</translation>
    </message>
    <message>
        <source>Always add description to status</source>
        <translation>Zawsze dodaj opis do statusu</translation>
    </message>
</context>
</TS>

==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/filedesc/translations/filedesc_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>@default</name>
    <message>
        <source>FileDesc</source>
        <translation>FileDesc</translation>
    </message>
    <message>
        <source>File with description to synchronize</source>
        <translation>Plik z opisem do synchronizacji</translation>
    </message>
    <message>
        <source>Enter here a file, which will contain descriptions to refresh by module.</source>
        <translation>Wpisz tutaj nazwę pliku, który będzie zawierał opisy do odświeżania przez moduł.</translation>
    </message>
    <message>
        <source>If you choose status without description, module will set it automatically to similar but with description</source>
        <translation>Jeśli wybierzesz status bez opisu, moduł automatycznie ustawi analogiczny, ale z opisem</translation>
    </message>
    <message>
        <source>Allow other descriptions</source>
        <translation>Dopuść inne opisy</translation>
    </message>
    <message>
        <source>Allows you to set some custom description manualy, until file contents does not change</source>
        <translation>Umożliwia ustawienie własnego opisu dopóki zawartość pliku nie ulegnie zmianie</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Zachowanie</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Opis</translation>
    </message>
    <message>
        <source>Always add description to status</source>
        <translation>Zawsze dodaj opis do statusu</translation>
    </message>
</context>
</TS>
